package ui

import (
	t_ui "icdb/pkg/types/ui"
	"image/color"

	"gioui.org/layout"
	"gioui.org/unit"
	"gioui.org/widget"
	"gioui.org/widget/material"
)

var (
	mainButton     widget.Clickable
	partsButton    widget.Clickable
	settingsButton widget.Clickable
)

var sidebarWidth = unit.Dp(200)
var sidebarBackground = color.NRGBA{R: 240, G: 240, B: 240, A: 255}

// renderSidebar creates the sidebar UI.
func renderSidebar(th *material.Theme) layout.Widget {
	return func(gtx layout.Context) layout.Dimensions {
		return layout.Flex{
			Axis: layout.Vertical,
		}.Layout(gtx,
			layout.Rigid(renderNavButton(gtx, th, "Main", &mainButton, t_ui.UIViewMain)),
			layout.Rigid(renderNavButton(gtx, th, "Parts", &partsButton, t_ui.UIViewParts)),
			layout.Rigid(renderNavButton(gtx, th, "Settings", &settingsButton, t_ui.UIViewSettings)),
		)
	}
}

// renderNavButton creates a navigation button
func renderNavButton(gtx layout.Context, th *material.Theme, label string, btn *widget.Clickable, target t_ui.UIView) layout.Widget {
	return func(gtx layout.Context) layout.Dimensions {
		if btn.Clicked(gtx) {
			currentView = target
		}
		return material.Button(th, btn, label).Layout(gtx)
	}
}
